package com.ducaller.sdkapplication;

import android.Manifest;
import android.app.Activity;
import android.content.Intent;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.provider.Settings;
import android.support.v4.app.ActivityCompat;
import android.text.TextUtils;
import android.view.View;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.EditText;
import android.widget.Toast;

import com.ducaller.fsdk.main.DuCallerSDKHelper;
import com.ducaller.sdkapplication.util.SharedPreferenceUtil;
import com.mobula.sample.R;


public class MainActivity extends Activity {
    private EditText mEtLabel;
    private Button mBtSet;
    private CheckBox mCbEnabledStatus;
    private CheckBox mCbFlowView;

    private Button mSDKSwitch;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        mEtLabel = (EditText) findViewById(R.id.et_label);
        mBtSet = (Button) findViewById(R.id.bt_set);
        mCbEnabledStatus = (CheckBox) findViewById(R.id.cb_enabled);
        mCbFlowView = (CheckBox) findViewById(R.id.cb_flowview);
        mSDKSwitch = (Button) findViewById(R.id.switch_sdk);

        initCheckBox();

        mCbFlowView.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {

                mCbFlowView.setChecked(isChecked);
                SharedPreferenceUtil.putBoolean(getApplicationContext(),
                        SharedPreferenceUtil.PRE_KEY_FLOWVIEW, isChecked);
                DuCallerSDKHelper.setFlowViewDisable(isChecked);

            }
        });

        mBtSet.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                String label = mEtLabel.getText().toString();
                if (!TextUtils.isEmpty(label)) {
                    // 设置卡片中自定义标题位置,设置完成会在用户确认隐私申明之前弹隐私声明。
                    // Set title
                    DuCallerSDKHelper.setDisplayAppLabel(label);
                    Toast.makeText(getApplicationContext(), "Set appLabel successful：" + label,
                            Toast.LENGTH_LONG).show();
                }
            }
        });

        mSDKSwitch.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (DuCallerSDKHelper.isEnabled()) {
                    mSDKSwitch.setText(R.string.str_btn_switch_open);
                    // 该方法只针对用户操作
                    // Allow user to enable caller function
                    DuCallerSDKHelper.disable();
                    mCbEnabledStatus.setChecked(false);
                } else {
                    mSDKSwitch.setText(R.string.str_btn_switch_close);
                    // 该方法只针对用户操作
                    // Allow user to disable caller function
                    DuCallerSDKHelper.enable();
                    mCbEnabledStatus.setChecked(true);
                }
            }
        });

        if (Build.VERSION.SDK_INT >= 23) {
            ActivityCompat.requestPermissions(this,
                    new String[]{Manifest.permission.READ_CONTACTS,
                            Manifest.permission.READ_PHONE_STATE,
                            Manifest.permission.SYSTEM_ALERT_WINDOW,
                            Manifest.permission.PROCESS_OUTGOING_CALLS},
                    1);

            if (!Settings.canDrawOverlays(MainActivity.this)) {
                Intent intent = new Intent(Settings.ACTION_MANAGE_OVERLAY_PERMISSION,
                        Uri.parse("package:" + getPackageName()));
                startActivityForResult(intent, 10);
            }
        }
    }

    private void initCheckBox() {
        mCbEnabledStatus.setChecked(DuCallerSDKHelper.isEnabled());

        if (DuCallerSDKHelper.isEnabled()) {
            mSDKSwitch.setText(R.string.str_btn_switch_close);
        } else {
            mSDKSwitch.setText(R.string.str_btn_switch_open);
        }

        // 默认悬浮框是展示的
        mCbFlowView.setChecked(SharedPreferenceUtil.getBoolean(getApplicationContext(),
                SharedPreferenceUtil.PRE_KEY_FLOWVIEW, false));
    }

    @Override
    protected void onResume() {
        super.onResume();
        initCheckBox();
    }
}
